# spatialtis-core

[![Documentation Status](https://img.shields.io/readthedocs/spatialtis-core?logo=readthedocs&logoColor=white&style=flat-square)](https://spatialtis-core.readthedocs.io/en/latest?badge=latest)
![Build&Test](https://img.shields.io/github/workflow/status/Mr-Milk/spatialtis-core/Build?style=flat-square&logo=github)
![pypi version](https://img.shields.io/pypi/v/spatialtis_core?color=blue&logo=python&logoColor=white&style=flat-square)

This repo implement computation intense steps in SpatialTis
for a better performance.

### Installation

To install the release version
```shell
pip install spatialtis_core
```

To install the development version of the package, make sure you have Rust toolchain installed. The package is built using `maturin`.

> As of v0.1.2, we could build on stable Rust.
> 
```shell
git clone https://github.com/Mr-Milk/SpatialTis-core.git
cd SpatialTis-core

pip install maturin
maturin develop
```

### Wheel built for

|           | py3.7 | py3.8 | py3.9 | py3.10 |
|-----------|-------|-------|-------|--------|
| Windows   |  ✔️  |  ✔️   |  ✔️  |   ✔️   |
| Linux     | ✔️  |  ✔️   |  ✔️  |   ✔️   |
| MacOS     |   ✔️  |  ✔️   |  ✔️  |   ✔️   |
| MacOS-ARM |   ✔️  |  ✔️   |  ✔️  |   ✔️   |



